package
Version:
v0.0.0-...-2824b45
Opens a new window with list of versions in this module.
Published: Sep 1, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func Execute(namespace, selector, container, command string) error
-
func SimpleBackup(namespace, selector, container, path, dst string, parallel int, tag string, ...) (string, error)
-
func WaitForPods(namespace, selector string, desiredReplicas int) error
func Execute(namespace, selector, container, command string) error
Execute executes simple commands in a container
SimpleBackup performs backup
func WaitForPods(namespace, selector string, desiredReplicas int) error
WaitForPods waits for a given number of pods
Source Files
¶
Click to show internal directories.
Click to hide internal directories.